@@ -241,14 +241,14 @@ class PAAHead(ATSSHead):
             pos_scores,
             pos_label,
             pos_label_weight,
-            avg_factor=self.loss_cls.loss_weight,
+            avg_factor=1.0,
             reduction_override='none')
 
         loss_bbox = self.loss_bbox(
             pos_bbox_pred,
             pos_bbox_target,
             pos_bbox_weight,
-            avg_factor=self.loss_bbox.loss_weight,
+            avg_factor=1.0,  # keep same loss weight before reassign
             reduction_override='none')
 
         loss_cls = loss_cls.sum(-1)
